"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DecisionRecordService = void 0;
var md5_1 = require("ts-md5/dist/md5");
var DecisionRecordService = /** @class */ (function () {
    function DecisionRecordService(project) {
        this.project = project;
    }
    DecisionRecordService.prototype.scan = function () {
        var _this = this;
        var results = [];
        this.project.getSourceFiles()
            .filter(function (sourceFile) { return _this.isExtensionToInclude(sourceFile.getExtension()); })
            .forEach(function (sourceFile) {
            var decisionRecordOverview = {
                decisionRecordOverview: {
                    name: sourceFile.getBaseName(),
                    contentHash: _this.createContentHash(sourceFile),
                },
                filePath: sourceFile,
            };
            results.push(decisionRecordOverview);
        });
        return results;
    };
    DecisionRecordService.prototype.createDecisionRecordDetail = function (componentId, parentComponentId, requestedADR) {
        var adrDetail = {
            name: requestedADR.decisionRecordOverview.name,
            contentHash: requestedADR.decisionRecordOverview.contentHash,
            componentId: componentId,
            parentComponentId: parentComponentId,
            content: requestedADR.filePath.getFullText()
        };
        if (adrDetail.content != null
            && adrDetail.content.length > DecisionRecordService.MAX_DECISIONRECORD_NR_OF_CHARACTERS) {
            adrDetail.content = adrDetail.content.substring(0, DecisionRecordService.MAX_DECISIONRECORD_NR_OF_CHARACTERS);
        }
        return adrDetail;
    };
    DecisionRecordService.prototype.isExtensionToInclude = function (fileExtension) {
        var ext = fileExtension.toLocaleLowerCase('en-US');
        return '.md' === ext || '.ad' === ext || '.adr' === ext;
    };
    DecisionRecordService.prototype.createContentHash = function (sourceFile) {
        return md5_1.Md5.hashStr(sourceFile.getFullText());
    };
    DecisionRecordService.MAX_DECISIONRECORD_NR_OF_CHARACTERS = 50000;
    return DecisionRecordService;
}());
exports.DecisionRecordService = DecisionRecordService;
