"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DecoratorService = void 0;
var ts_morph_1 = require("ts-morph");
var domain_object_1 = require("../model/domain-object");
/**
 * Note: this does not find dependencies which use path mappings from tsconfig
 */
var DecoratorService = /** @class */ (function () {
    function DecoratorService(project) {
        this.project = project;
    }
    DecoratorService.prototype.scan = function () {
        var _this = this;
        var program = this.project.getProgram();
        var sourceFiles = this.project.getSourceFiles();
        var domainObjects = [];
        var sourceFileToComponentsMapping = new Map();
        var sourceFileToModulesMapping = new Map();
        sourceFiles.forEach(function (sf) {
            var filePath = sf.getFilePath();
            if ((filePath.endsWith(".ts") || filePath.endsWith(".tsx")) &&
                filePath.lastIndexOf(".d.ts") === -1 &&
                filePath.lastIndexOf("spec.ts") === -1) {
                if (!program.isSourceFileFromExternalLibrary(sf) &&
                    !sf.isInNodeModules()) {
                    var scannedFile = sf.compilerNode;
                    ts_morph_1.ts.forEachChild(scannedFile, function (node) {
                        if (node.decorators) {
                            var filterByDecorators = function (filteredNode) {
                                if (filteredNode.expression) {
                                    var _test = /(NgModule|Component|Injectable|Pipe|Directive)/.test(filteredNode.expression.getText());
                                    if (!_test && ts_morph_1.ts.isClassDeclaration(node)) {
                                        _test = true;
                                    }
                                    return _test;
                                }
                                if (ts_morph_1.ts.isClassDeclaration(node)) {
                                    return true;
                                }
                                return false;
                            };
                            var visitDecorator = function (visitedDecorator) {
                                if (_this.isComponent(visitedDecorator) ||
                                    _this.isModule(visitedDecorator)) {
                                    node.getChildren().forEach(function (child) {
                                        if (child.kind === ts_morph_1.SyntaxKind.Identifier) {
                                            // console.log(
                                            //   'found component : "' + child.getText() + '"'
                                            // );
                                            var domainObject = __assign(__assign({}, (0, domain_object_1.createDomainObject)()), { name: child.getText(), aggregateRoot: _this.isModule(visitedDecorator), fullyQualifiedName: sf.getFilePath() + "::" + child.getText() });
                                            domainObjects.push(domainObject);
                                            if (_this.isModule(visitedDecorator)) {
                                                if (sourceFileToModulesMapping.has(sf)) {
                                                    var sourceFileModules = sourceFileToModulesMapping.get(sf);
                                                    sourceFileToModulesMapping.set(sf, __spreadArray(__spreadArray([], sourceFileModules, true), [
                                                        domainObject
                                                    ], false));
                                                }
                                                else {
                                                    sourceFileToModulesMapping.set(sf, [domainObject]);
                                                }
                                            }
                                            else {
                                                if (sourceFileToComponentsMapping.has(sf)) {
                                                    var sourceFileComponents = sourceFileToComponentsMapping.get(sf);
                                                    sourceFileToComponentsMapping.set(sf, __spreadArray(__spreadArray([], sourceFileComponents, true), [
                                                        domainObject
                                                    ], false));
                                                }
                                                else {
                                                    sourceFileToComponentsMapping.set(sf, [domainObject]);
                                                }
                                            }
                                        }
                                    });
                                }
                            };
                            node.decorators
                                .filter(filterByDecorators)
                                .forEach(visitDecorator);
                        }
                    });
                }
            }
        });
        sourceFileToModulesMapping.forEach(function (modules, key) {
            key.getReferencedSourceFiles().forEach(function (refFile) {
                // add link to modules
                var referencedModules = sourceFileToModulesMapping.get(refFile);
                if (referencedModules != null) {
                    modules.forEach(function (module) {
                        referencedModules.forEach(function (referencedModule) {
                            return module.dependsOnEntityFullyQualifiedNames.push(referencedModule.fullyQualifiedName);
                        });
                    });
                }
                // add link to components
                var referencedComponents = sourceFileToComponentsMapping.get(refFile);
                if (referencedComponents != null) {
                    modules.forEach(function (module) {
                        referencedComponents.forEach(function (referencedComponents) {
                            return module.dependsOnEntityFullyQualifiedNames.push(referencedComponents.fullyQualifiedName);
                        });
                    });
                }
            });
        });
        return domainObjects;
    };
    DecoratorService.prototype.isComponent = function (decorator) {
        return this.parseDecorator(decorator, "Component");
    };
    DecoratorService.prototype.isModule = function (decorator) {
        return this.parseDecorator(decorator, "NgModule");
    };
    DecoratorService.prototype.parseDecorator = function (decorator, type) {
        var result = false;
        if (decorator.expression) {
            if (decorator.expression.getText() &&
                decorator.expression.getText().startsWith(type)) {
                result = true;
            }
        }
        return result;
    };
    return DecoratorService;
}());
exports.DecoratorService = DecoratorService;
