"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EntityService = void 0;
var reflection_service_1 = require("./reflection.service");
var EntityService = /** @class */ (function () {
    function EntityService(project) {
        this.project = project;
        this.reflectionService = new reflection_service_1.ReflectionService();
    }
    EntityService.prototype.scan = function () {
        var _this = this;
        var domainObjects = [];
        this.reflectionService.visitClassDecorators(this.project, function (d, classDeclaration) {
            var domainObject = _this.getDomainObjectFromDecorator(d, classDeclaration);
            if (domainObject != null) {
                domainObjects.push(domainObject);
            }
        });
        return domainObjects;
    };
    EntityService.prototype.getDomainObjectFromDecorator = function (d, classDeclaration) {
        var name;
        var aggregateRoot = false;
        if (d.getFullName() === 'ContextEntity' && d.isDecoratorFactory()) {
            name = this.reflectionService.getValueFromDecorator(d, "ContextEntity");
        }
        else if (d.getFullName() === 'ContextAggregateRoot' && d.isDecoratorFactory()) {
            aggregateRoot = true;
            name = this.reflectionService.getValueFromDecorator(d, "ContextAggregateRoot");
        }
        else {
            return null;
        }
        var className = (name == null ? classDeclaration.getName() : name);
        var fullyQualifiedName = classDeclaration.getSourceFile().getFilePath() + '.' + className;
        var fields = classDeclaration.getInstanceProperties()
            .map(function (prop) {
            try {
                var field = {
                    name: prop.getName(),
                    typeName: prop.getStructure().type,
                    typeFullyQualifiedName: prop.getType().getText(),
                };
                // if no type is specified in the declaration, only an assignment
                // then get intrinsic type based on the value
                if (field.typeName == null) {
                    field.typeName = prop.getType().getText();
                }
                return field;
            }
            catch (error) {
                return null;
            }
        })
            .filter(function (field) { return field != null; })
            .map(function (field) { return field; });
        return {
            name: className,
            aggregateRoot: aggregateRoot,
            baseTypeNames: [],
            dependsOnEntityFullyQualifiedNames: [],
            fields: fields,
            fullyQualifiedName: fullyQualifiedName,
            implementationTypeNames: []
        };
        return null;
    };
    return EntityService;
}());
exports.EntityService = EntityService;
