"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FeatureFileService = void 0;
var ts_md5_1 = require("ts-md5");
var FeatureFileService = /** @class */ (function () {
    function FeatureFileService(project) {
        this.project = project;
    }
    FeatureFileService.prototype.scan = function () {
        var _this = this;
        var results = [];
        this.project.getSourceFiles()
            .filter(function (sourceFile) { return _this.isExtensionToInclude(sourceFile.getExtension()); })
            .forEach(function (sourceFile) {
            var featureFileOverview = {
                featureFileOverview: {
                    name: sourceFile.getBaseName(),
                    contentHash: _this.createContentHash(sourceFile),
                },
                filePath: sourceFile,
            };
            results.push(featureFileOverview);
        });
        return results;
    };
    FeatureFileService.prototype.createFeatureFileDetail = function (componentId, parentComponentId, requestedFF) {
        var ffDetail = {
            name: requestedFF.featureFileOverview.name,
            contentHash: requestedFF.featureFileOverview.contentHash,
            content: requestedFF.filePath.getFullText(),
            componentId: componentId,
            parentComponentId: parentComponentId,
        };
        if (ffDetail.content != null
            && ffDetail.content.length > FeatureFileService.MAX_FEATUREFILE_NR_OF_CHARACTERS) {
            ffDetail.content = ffDetail.content.substring(0, FeatureFileService.MAX_FEATUREFILE_NR_OF_CHARACTERS);
        }
        return ffDetail;
    };
    FeatureFileService.prototype.isExtensionToInclude = function (fileExtension) {
        var ext = fileExtension.toLocaleLowerCase('en-US');
        return '.feature' === ext || '.story' === ext;
    };
    FeatureFileService.prototype.createContentHash = function (sourceFile) {
        return ts_md5_1.Md5.hashStr(sourceFile.getFullText());
    };
    FeatureFileService.MAX_FEATUREFILE_NR_OF_CHARACTERS = 80000;
    return FeatureFileService;
}());
exports.FeatureFileService = FeatureFileService;
