"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GlossaryService = void 0;
var reflection_service_1 = require("./reflection.service");
var GlossaryService = /** @class */ (function () {
    function GlossaryService(project) {
        this.project = project;
        this.reflectionService = new reflection_service_1.ReflectionService();
    }
    GlossaryService.prototype.scan = function () {
        var _this = this;
        var glossaryTerms = [];
        this.reflectionService.visitClassDecorators(this.project, function (d, classDeclaration) {
            var glossaryTerm = _this.getGlossaryTermFromDecorator(d, classDeclaration);
            if (glossaryTerm != null) {
                glossaryTerms.push(glossaryTerm);
            }
        });
        return glossaryTerms;
    };
    GlossaryService.prototype.getGlossaryTermFromDecorator = function (d, classDeclaration) {
        if (d.getFullName() !== 'ContextGlossary') {
            return null;
        }
        var name = this.reflectionService.getValueFromDecorator(d, 'ContextGlossary', 'name');
        var definition = this.reflectionService.getValueFromDecorator(d, 'ContextGlossary', 'definition');
        var aliases = this.reflectionService.getValueFromDecorator(d, 'ContextGlossary', 'aliases');
        if (name == null || name.length === 0) {
            name = classDeclaration.getName();
        }
        var term = {
            name: name,
            aliases: aliases,
            definition: definition,
        };
        return term;
    };
    return GlossaryService;
}());
exports.GlossaryService = GlossaryService;
