"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LanguagesService = void 0;
var LanguagesService = /** @class */ (function () {
    function LanguagesService(project) {
        var _this = this;
        this.project = project;
        this.integerMaxValue = 2147483647;
        this.languages = [
            newLanguage('Java', ['.java'], []),
            newLanguage('Kotlin', ['.kt', '.ktm', '.kts'], []),
            newLanguage('Scala', ['.scala', '.sc'], []),
            newLanguage('Clojure', ['.clj', '.cljc', '.cljs', '.cljx'], []),
            newLanguage('Scaml', ['.scaml'], []),
            newLanguage('Jasper Report', ['.jrxml', '.jrtx'], []),
            newLanguage('Javascript', ['.js'], []),
            newLanguage('Typescript', ['.ts', '.tsx'], []),
            newLanguage('Java Server Pages', ['.jsp'], []),
            newLanguage('Java Server Faces', ['.jsf', '.faces'], []),
            newLanguage('Groovy', ['.groovy'], ['Jenkinsfile']),
            newLanguage('Dockerfile', ['.dockerfile'], ['Dockerfile']),
            newLanguage('Yaml', ['.yml', '.yaml'], []),
            newLanguage('Text', ['.txt'], []),
            newLanguage('Gherkin', ['.feature', '.story'], []),
            newLanguage('AsciiDoc', ['.asciidoc', '.adoc'], []),
            newLanguage('Markdown', ['.md', '.markdown', '.adr'], []),
            newLanguage('HTML', ['.html', '.htm', '.xhtml'], []),
            newLanguage('SQL', ['.sql', '.mysql'], []),
            newLanguage('PLSQL', ['.plsql', '.pkb', '.pks'], []),
            newLanguage('XML', ['.xml', '.wsdl'], ['.project', '.classpath']),
            newLanguage('XSLT', ['.xslt', '.xsl'], []),
            newLanguage('SVG', ['.svg'], []),
            newLanguage('CSS', ['.css'], []),
            newLanguage('SCSS', ['.scss'], []),
            newLanguage('Less', ['.less'], []),
            newLanguage('CSV', ['.csv'], []),
            newLanguage('Sass', ['.sass'], []),
            newLanguage('Batchfile', ['.bat', '.cmd'], []),
            newLanguage('Shell', ['.sh', '.bash', '.ksh', '.zsh'], []),
            newLanguage('Properties', ['.properties'], []),
            newLanguage('Maven POM', [], ['pom.xml']),
            newLanguage('JAR Manifest', [], ['MANIFEST.MF']),
            newLanguage('Gradle', ['.gradle'], []),
            newLanguage('Apache Conf', [], ['.htaccess', 'apache2.conf', 'httpd.conf']),
            newLanguage('NPM Config', [], ['.npmrc']),
        ];
        this.filenameToLanguage = new Map();
        this.extensionToLanguage = new Map();
        this.languages.forEach(function (language) {
            language.extensions.forEach(function (ext) {
                _this.extensionToLanguage.set(ext.toLocaleLowerCase('en-US'), language);
            });
            language.filenames.forEach(function (filename) {
                _this.filenameToLanguage.set(filename.toLocaleLowerCase('en-US'), language);
            });
        });
    }
    LanguagesService.prototype.getBytesOfCodePerLanguage = function () {
        var _this = this;
        var bytesOfCodePerLanguage = new Map();
        this.project.getSourceFiles().forEach(function (sourceFile) {
            var filename = sourceFile.getBaseName();
            filename = filename.toLocaleLowerCase('en-US');
            // console.log('file: ' + filename + '    ' + sourceFile.getDirectoryPath())
            // first check whether its a special filename
            var language = _this.filenameToLanguage.get(filename);
            // otherwise check using the extension
            if (language == null && filename.indexOf('.') >= 0) {
                var extensionIncludingDot = sourceFile.getExtension();
                language = _this.extensionToLanguage.get(extensionIncludingDot);
            }
            // if its a known language then add the count
            if (language != null) {
                var count = bytesOfCodePerLanguage.get(language);
                if (count == null) {
                    count = 0;
                }
                var nrOfBytes = sourceFile.getFullText().length;
                // Ensuring not to overflow
                if (_this.integerMaxValue - nrOfBytes > count) {
                    count += nrOfBytes;
                }
                else {
                    count = _this.integerMaxValue - 1;
                }
                bytesOfCodePerLanguage.set(language, count);
            }
        });
        var results = [];
        bytesOfCodePerLanguage.forEach(function (value, key) {
            results.push({
                language: key.name,
                amount: value,
            });
        });
        return results;
    };
    return LanguagesService;
}());
exports.LanguagesService = LanguagesService;
function newLanguage(name, extensions, filenames) {
    return {
        name: name,
        extensions: extensions,
        filenames: filenames
    };
}
