"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReflectionService = void 0;
var ts_morph_1 = require("ts-morph");
var ReflectionService = /** @class */ (function () {
    function ReflectionService() {
    }
    ReflectionService.prototype.getValueFromDecorator = function (d, annotationName, parameterName) {
        var _this = this;
        if (parameterName === void 0) { parameterName = null; }
        var result = null;
        if (d.getFullName() === annotationName && d.isDecoratorFactory()) {
            d.getArguments().forEach(function (arg) {
                var _a, _b;
                if (arg.getKind() === ts_morph_1.SyntaxKind.StringLiteral) {
                    result = arg.getLiteralValue();
                }
                else if (arg.getKind() === ts_morph_1.SyntaxKind.ObjectLiteralExpression && parameterName != null) {
                    var property = arg.getProperty(parameterName);
                    if (property != null && (property === null || property === void 0 ? void 0 : property.getKind()) === ts_morph_1.SyntaxKind.PropertyAssignment) {
                        if (((_a = property.getInitializer()) === null || _a === void 0 ? void 0 : _a.getKind()) === ts_morph_1.SyntaxKind.StringLiteral) {
                            result = property.getInitializer().getLiteralValue();
                        }
                        else if (((_b = property.getInitializer()) === null || _b === void 0 ? void 0 : _b.getKind()) === ts_morph_1.SyntaxKind.ArrayLiteralExpression) {
                            var node = property.getInitializer();
                            result = _this.getArrayValueFromNode(node);
                        }
                    }
                }
            });
        }
        return result;
    };
    ReflectionService.prototype.getArrayValueFromDecorator = function (d, annotationName) {
        var _this = this;
        var result = [];
        if (d.getFullName() === annotationName && d.isDecoratorFactory()) {
            d.getArguments().forEach(function (arg) {
                if (arg.getKind() === ts_morph_1.SyntaxKind.ArrayLiteralExpression) {
                    result.push.apply(result, _this.getArrayValueFromNode(arg));
                }
            });
        }
        return result;
    };
    ReflectionService.prototype.getArrayValueFromNode = function (node) {
        var result = [];
        var elements = node.getElements();
        elements.filter(function (ele) { return ele.getKind() === ts_morph_1.SyntaxKind.StringLiteral; })
            .map(function (ele) { return ele.getLiteralValue(); })
            .forEach(function (name) { return result.push(name); });
        return result;
    };
    ReflectionService.prototype.visitClassDecorators = function (project, callback) {
        project.getSourceFiles().forEach(function (sourceFile) {
            sourceFile.getClasses().forEach(function (classDeclaration) {
                classDeclaration.getDecorators().forEach(function (d) { return callback(d, classDeclaration); });
            });
        });
    };
    return ReflectionService;
}());
exports.ReflectionService = ReflectionService;
