"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TechnologyStackService = void 0;
var technology_1 = require("../model/technology");
var async_call_blocker_1 = require("../infrastructure/async-call-blocker");
var readJson = require("read-package-json");
var TechnologyStackService = /** @class */ (function () {
    function TechnologyStackService() {
        this.technologies = [
            libFor("@angular/core", "Angular Core"),
            libFor("@angular/material", "Angular Material"),
            libFor("@angular/forms", "Angular Forms"),
            libFor("@angular/router", "Angular Router"),
            libFor("rxjs", "RxJS"),
            libFor("@ngrx/effects", "NgRx Effects"),
            libFor("@ngrx/store", "NgRx Store"),
            libFor("@ngrx/router-store", "NgRx Router Store")
        ];
    }
    TechnologyStackService.prototype.scan = function () {
        var _this = this;
        var packageJsonContent = this.readPackageJson("package.json");
        if (packageJsonContent == null || packageJsonContent.dependencies == null) {
            return [];
        }
        return Object.keys(packageJsonContent.dependencies).map(function (key) {
            var version = packageJsonContent.dependencies[key];
            var tech = __assign(__assign({}, (0, technology_1.createTechnology)()), { version: version, technicalName: key });
            var lib = _this.technologies.find(function (tech) { return tech.technicalName === key; });
            if (!!lib) {
                tech.wellKnown = true;
                tech.displayName = lib.displayName;
            }
            return tech;
        });
    };
    TechnologyStackService.prototype.readPackageJson = function (file) {
        var fileContent = null;
        readJson(file, null, false, function (er, data) {
            if (er) {
                console.error("Error: There was an error reading package.json");
                return;
            }
            fileContent = data;
        });
        // Block until file is read
        while (!fileContent) {
            (0, async_call_blocker_1.blockExecution)();
        }
        return fileContent;
    };
    return TechnologyStackService;
}());
exports.TechnologyStackService = TechnologyStackService;
function libFor(technicalName, displayName) {
    return { displayName: displayName, technicalName: technicalName };
}
